Conclusion and Future Work
==========================

Conclusion
----------

We accomplished two out of our three main objectives:
developing an accessible website and create a collaborative platform.
However, there are rooms for improvement in the implementation.

Future Work
-----------

In the future, we will realize features that have not been implemented:

- Task management
- Jury's role and evaluation
- Notification
- Task discussion
- Statistical reports for academic assistant

On top of that, we need to refine existing features:

- Implement a method that prevents user.
- Add configuration for maximum and minimum grade.
- Check file types for reports and slides.
- Improve user interface and user experience.
